PrimalCertificateResiduals

Struct PrimalCertificateResiduals 

pub struct PrimalCertificateResiduals {
    pub stationarity: f64,
    pub support_gap: f64,
    pub cone_violation: f64,
}
Independently recomputed residuals of a PrimalCertificate.

The certificate is valid to tolerance eps when stationarity <= eps, cone_violation <= eps, and support_gap <= -eps (for a certificate normalized to unit infinity norm).

Fields

stationarity: f64

||A_e' y_e + A_i' y_i + y_b||_inf; zero for an exact certificate.

support_gap: f64

b_e' y_e + b_i' y_i + u'(y_b)+ + l'(y_b)- over finite bounds; strictly negative for a valid certificate.

cone_violation: f64

Largest violation of the certificate cone: negative inequality weights, or bound weights citing an infinite bound.